from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean

Bedtools_Groupby_V0_1_0 = CommandToolBuilder(tool="bedtools_groupby", base_command=["bedtools", "groupby"], inputs=[ToolInput(tag="in_input_file_assumes", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="Input file. Assumes 'stdin' if omitted.")), ToolInput(tag="in_grp", input_type=Boolean(optional=True), prefix="-grp", doc=InputDocumentation(doc="Specify the columns (1-based) for the grouping.\nThe columns must be comma separated.\n- Default: 1,2,3")), ToolInput(tag="in_op_cols", input_type=Boolean(optional=True), prefix="-opCols", doc=InputDocumentation(doc="Specify the column (1-based) that should be summarized.\n- Required.")), ToolInput(tag="in_ops", input_type=Boolean(optional=True), prefix="-ops", doc=InputDocumentation(doc="Specify the operation that should be applied to opCol.\nValid operations:\nsum, count, count_distinct, min, max,\nmean, median, mode, antimode,\nstdev, sstdev (sample standard dev.),\ncollapse (i.e., print a comma separated list (duplicates allowed)),\ndistinct (i.e., print a comma separated list (NO duplicates allowed)),\ndistinct_sort_num (as distinct, but sorted numerically, ascending),\ndistinct_sort_num_desc (as distinct, but sorted numerically, descending),\nconcat   (i.e., merge values into a single, non-delimited string),\nfreqdesc (i.e., print desc. list of values:freq)\nfreqasc (i.e., print asc. list of values:freq)\nfirst (i.e., print first value)\nlast (i.e., print last value)\n- Default: sum\nIf there is only column, but multiple operations, all operations will be\napplied on that column. Likewise, if there is only one operation, but\nmultiple columns, that operation will be applied to all columns.\nOtherwise, the number of columns must match the the number of operations,\nand will be applied in respective order.\nE.g., '-c 5,4,6 -o sum,mean,count' will give the sum of column 5,\nthe mean of column 4, and the count of column 6.\nThe order of output columns will match the ordering given in the command.")), ToolInput(tag="in_full", input_type=Boolean(optional=True), prefix="-full", doc=InputDocumentation(doc="Print all columns from input file.  The first line in the group is used.\nDefault: print only grouped columns.")), ToolInput(tag="in_in_header", input_type=Boolean(optional=True), prefix="-inheader", doc=InputDocumentation(doc="Input file has a header line - the first line will be ignored.")), ToolInput(tag="in_out_header", input_type=Boolean(optional=True), prefix="-outheader", doc=InputDocumentation(doc="Print header line in the output, detailing the column names.\nIf the input file has headers (-inheader), the output file\nwill use the input's column names.\nIf the input file has no headers, the output file\nwill use 'col_1', 'col_2', etc. as the column names.")), ToolInput(tag="in_header", input_type=Boolean(optional=True), prefix="-header", doc=InputDocumentation(doc="same as '-inheader -outheader'")), ToolInput(tag="in_ignorecase", input_type=Boolean(optional=True), prefix="-ignorecase", doc=InputDocumentation(doc="Group values regardless of upper/lower case.")), ToolInput(tag="in_prec", input_type=Boolean(optional=True), prefix="-prec", doc=InputDocumentation(doc="Sets the decimal precision for output (Default: 5)")), ToolInput(tag="in_delim", input_type=Boolean(optional=True), prefix="-delim", doc=InputDocumentation(doc="Specify a custom delimiter for the collapse operations.\n- Example: -delim '|'\n- Default: ','."))], outputs=[], container="quay.io/biocontainers/bedtools:2.30.0--hc088bd4_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Bedtools_Groupby_V0_1_0().translate("wdl")

